You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:12:03 UTC

svn commit: r1591060 [2/15] - in /openoffice/trunk/main: helpcontent2/source/text/scalc/01/ helpcontent2/source/text/shared/01/ helpcontent2/source/text/simpress/01/ helpcontent2/source/text/smath/01/ helpcontent2/source/text/swriter/01/ helpcontent2/s...

Modified: openoffice/trunk/main/javaunohelper/com/sun/star/comp/helper/SharedLibraryLoader.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/javaunohelper/com/sun/star/comp/helper/SharedLibraryLoader.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/javaunohelper/com/sun/star/comp/helper/SharedLibraryLoader.java (original)
+++ openoffice/trunk/main/javaunohelper/com/sun/star/comp/helper/SharedLibraryLoader.java Tue Apr 29 19:11:53 2014
@@ -113,7 +113,7 @@ public class SharedLibraryLoader {
 	/**
 	 * Registers the SharedLibraryLoader under a RegistryKey.
 	 * <p>
-	 * @return	true if the registration was successfull - otherwise false
+	 * @return	true if the registration was successful - otherwise false
 	 * @param	smgr	the ServiceManager
 	 * @param	regKey	the root key under that the component should be registered
 	 * @see		com.sun.star.loader.SharedLibrary
@@ -132,7 +132,7 @@ public class SharedLibraryLoader {
 	/**
 	 * Registers the SharedLibraryLoader under a RegistryKey.
 	 * <p>
-	 * @return	true if the registration was successfull - otherwise false
+	 * @return	true if the registration was successful - otherwise false
 	 * @param	libName	name of the shared library
 	 * @param	smgr	the ServiceManager
 	 * @param	regKey	the root key under that the component should be registered

Modified: openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/InterfaceContainer.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/InterfaceContainer.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/InterfaceContainer.java (original)
+++ openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/InterfaceContainer.java Tue Apr 29 19:11:53 2014
@@ -77,7 +77,7 @@ import com.sun.star.uno.UnoRuntime;
  *  is removed.
  *  ListIterator.set is not supported.
  *
- * A lot of  methods resemble those of the  to java.util.List interface, allthough
+ * A lot of  methods resemble those of the  to java.util.List interface, although
  * this class does not implement it. However, the list iterators returned, for example by
  * the listIterator method implement the java.util.ListIterator interface.
  * Implementing the List interface would mean to support all none - optional methods as
@@ -86,9 +86,9 @@ import com.sun.star.uno.UnoRuntime;
  * list have to cause changes in the main list. This is a problem, since this class is to be
  * used in a multi-threaded environment. The sub list could work on a copy as the iterators
  * do, but all the functions which work on an given index could not be properly supported.
- * Unfortunatly, the List interface documentation states that all optional methods implemented
+ * Unfortunately, the List interface documentation states that all optional methods implemented
  * by the list have to be implemented in the sub list. That would mean to do without all those
- * critical methods, allthough they might work well in the "main list" (as opposed to sub list).
+ * critical methods, although they might work well in the "main list" (as opposed to sub list).
  */
 public class InterfaceContainer implements Cloneable
 {
@@ -348,7 +348,7 @@ public class InterfaceContainer implemen
     }
     
     /**
-     * Searches for the first occurence of the given argument, testing
+     * Searches for the first occurrence of the given argument, testing
      * for equality using the <tt>equals</tt> method.
      *
      * @param   elem   an object.

Modified: openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/MultiTypeInterfaceContainer.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/MultiTypeInterfaceContainer.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/MultiTypeInterfaceContainer.java (original)
+++ openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/MultiTypeInterfaceContainer.java Tue Apr 29 19:11:53 2014
@@ -113,7 +113,7 @@ public class MultiTypeInterfaceContainer
         // equals. For example:
         // Type a= new Type(XInterface.class);
         // Type b= new Type(XInterface.class);
-        // Allthough a != b , the map interprets both as being the same.
+        // Although a != b , the map interprets both as being the same.
         InterfaceContainer cont= (InterfaceContainer) map.get(ckey);
         if (cont != null)
         {

Modified: openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/PropertySet.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/PropertySet.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/javaunohelper/test/com/sun/star/comp/helper/SharedLibraryLoader_Test.java (original)
+++ openoffice/trunk/main/javaunohelper/test/com/sun/star/comp/helper/SharedLibraryLoader_Test.java Tue Apr 29 19:11:53 2014
@@ -67,7 +67,7 @@ public class SharedLibraryLoader_Test {
 		sharedLibraryLoaderFactory = SharedLibraryLoader.getServiceFactory(null, null);
 		
 		System.out.print("Test - ");
-		System.out.println(sharedLibraryLoaderFactory == null? "failed" : "successfull");		
+		System.out.println(sharedLibraryLoaderFactory == null? "failed" : "successful");		
 		System.out.println("*******************************************************************");
 		System.out.println();
 		
@@ -88,7 +88,7 @@ public class SharedLibraryLoader_Test {
 				XImplementationLoader.class, sharedLibraryLoaderFactory.createInstance() );
 		
 		System.out.print("Test - ");
-		System.out.println(sharedLibraryLoader == null? "failed" : "successfull");		
+		System.out.println(sharedLibraryLoader == null? "failed" : "successful");		
 		System.out.println("*******************************************************************");
 		System.out.println();
 		
@@ -115,7 +115,7 @@ public class SharedLibraryLoader_Test {
 		nativeServiceManager = UnoRuntime.queryInterface( XMultiServiceFactory.class, aSMgrFac.createInstance() );
 		
 		System.out.print("Test - ");
-		System.out.println(nativeServiceManager == null? "failed" : "successfull");
+		System.out.println(nativeServiceManager == null? "failed" : "successful");
 		
 		System.out.println("*******************************************************************");
 		System.out.println();
@@ -141,7 +141,7 @@ public class SharedLibraryLoader_Test {
 		simpleRegistry = 
 			UnoRuntime.queryInterface( XSimpleRegistry.class, aRegFac.createInstance() );
 		System.out.print("Test - ");
-		System.out.println(simpleRegistry == null? "failed" : "successfull");
+		System.out.println(simpleRegistry == null? "failed" : "successful");
 		System.out.println("*******************************************************************");
 		System.err.println();			
 		return true;
@@ -162,7 +162,7 @@ public class SharedLibraryLoader_Test {
 		result = SharedLibraryLoader.writeRegistryServiceInfo( null,  regKey );
 		
 		System.out.print("Test - ");
-		System.out.println( result==false ? "failed" : "successfull");
+		System.out.println( result==false ? "failed" : "successful");
 		System.out.println("*******************************************************************");
 		System.out.println();
 		return result;

Modified: openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/ComponentBase_Test.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/ComponentBase_Test.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/ComponentBase_Test.java (original)
+++ openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/ComponentBase_Test.java Tue Apr 29 19:11:53 2014
@@ -79,7 +79,7 @@ public class ComponentBase_Test
         obj1.nDisposingCalled= 0;
         obj2.nDisposingCalled= 0;
         obj3.nDisposingCalled= 0;
-        comp.dispose(); // allready disposed;
+        comp.dispose(); // already disposed;
         r[i++]= obj1.nDisposingCalled == 0;
         
         boolean bOk= true;
@@ -139,7 +139,7 @@ public class ComponentBase_Test
         for (int c= 0; c < i; c++)
             bOk= bOk && r[c];
         if (bOk == false)
-            System.out.println("Errors occured!");
+            System.out.println("Errors occurred!");
         else
             System.out.println("No errors.");
 

Modified: openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/Factory_Test.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/Factory_Test.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/Factory_Test.java (original)
+++ openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/Factory_Test.java Tue Apr 29 19:11:53 2014
@@ -194,7 +194,7 @@ public class Factory_Test
         }
         catch (Exception exc)
         {
-            System.err.println( ">>>>>>>>>> exc occured: " + exc.toString() );
+            System.err.println( ">>>>>>>>>> exc occurred: " + exc.toString() );
             exc.printStackTrace();
         }
         System.exit( 0 );

Modified: openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/InterfaceContainer_Test.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/InterfaceContainer_Test.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/InterfaceContainer_Test.java (original)
+++ openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/InterfaceContainer_Test.java Tue Apr 29 19:11:53 2014
@@ -979,7 +979,7 @@ public class InterfaceContainer_Test
         for (int c= 0; c < i; c++)
             bOk= bOk && r[c];
         if ( ! bOk )
-            System.out.println("Test finished.\nErrors occured!!!");
+            System.out.println("Test finished.\nErrors occurred!!!");
         else
             System.out.println("Test finished. \nNo errors.");
         

Modified: openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/MultiTypeInterfaceContainer_Test.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/MultiTypeInterfaceContainer_Test.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/MultiTypeInterfaceContainer_Test.java (original)
+++ openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/MultiTypeInterfaceContainer_Test.java Tue Apr 29 19:11:53 2014
@@ -357,7 +357,7 @@ public class MultiTypeInterfaceContainer
         for (int c= 0; c < i; c++)
             bOk= bOk && r[c];
         if ( ! bOk )
-            System.out.println("Test finished.\nErrors occured!!!");
+            System.out.println("Test finished.\nErrors occurred!!!");
         else
             System.out.println("Test finished. \nNo errors.");
    

Modified: openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/PropertySet_Test.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/PropertySet_Test.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/PropertySet_Test.java (original)
+++ openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/PropertySet_Test.java Tue Apr 29 19:11:53 2014
@@ -1075,7 +1075,7 @@ public class PropertySet_Test
         for (int c= 0; c < i; c++)
             bOk= bOk && r[c];
         if (bOk == false)
-            System.out.println("Errors occured!");
+            System.out.println("Errors occurred!");
         else
             System.out.println("No errors.");
         return bOk;
@@ -1121,7 +1121,7 @@ class TestClass extends PropertySet
     public Property propEnum = 
         new Property("PropEnum", 14, new Type("com.sun.star.beans.PropertyState", TypeClass.ENUM), (short)0);
     public com.sun.star.beans.PropertyState enumPropertyState = com.sun.star.beans.PropertyState.DEFAULT_VALUE;
-    // Test private, protected, package access, Anys as arguments and members, members whith a value
+    // Test private, protected, package access, Anys as arguments and members, members with a value
 
     public Property propBoolB= new Property("PropBoolB", 101, new Type(Boolean.TYPE), (short) 0);
     protected boolean boolPropB;

Modified: openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/WeakBase_Test.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/WeakBase_Test.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/WeakBase_Test.java (original)
+++ openoffice/trunk/main/javaunohelper/test/com/sun/star/lib/uno/helper/WeakBase_Test.java Tue Apr 29 19:11:53 2014
@@ -195,7 +195,7 @@ public class WeakBase_Test
         for (int c= 0; c < i; c++)
             bOk= bOk && r[c];
         if (bOk == false)
-            System.out.println("Errors occured!");
+            System.out.println("Errors occurred!");
         else
             System.out.println("No errors.");
 

Modified: openoffice/trunk/main/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/jurt/com/sun/star/comp/servicemanager/ServiceManager.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/jurt/com/sun/star/comp/servicemanager/ServiceManager.java (original)
+++ openoffice/trunk/main/jurt/com/sun/star/comp/servicemanager/ServiceManager.java Tue Apr 29 19:11:53 2014
@@ -119,7 +119,7 @@ public class ServiceManager implements X
 	 * @return     the factory for the <code>ServiceManager</code>.
 	 * @param      implName		the implementation name of the of the service. 
 	 *                          Must be equal to <code>com.sun.star.comp.servicemanager.ServicManager</code>
-	 * @param	   multiFactory	refernce of the <code>MultiServiceFactory</code>. This parameter will be ignored.
+	 * @param	   multiFactory	references of the <code>MultiServiceFactory</code>. This parameter will be ignored.
 	 * @param	   regKey		the root key of the registry. This parameter will be ignored. 	
 	 */
   	public static XSingleServiceFactory getServiceFactory( String implName, 
@@ -158,7 +158,7 @@ public class ServiceManager implements X
      * Registers a list of components given by their class names.
      * <p> 
      * @param 	newImpls	list of the components that should be registered, given by their class names.
-     *						If any exception occured during the registration, the process will be canceled.
+     *						If any exception occurred during the registration, the process will be canceled.
      * @see 	com.sun.star.container.XSet
      */
     private void xaddFactories( String[] newImpls ) 

Modified: openoffice/trunk/main/jurt/com/sun/star/lib/uno/environments/remote/IThreadPool.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/jurt/com/sun/star/lib/uno/environments/remote/IThreadPool.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/jurt/com/sun/star/lib/uno/environments/remote/IThreadPool.java (original)
+++ openoffice/trunk/main/jurt/com/sun/star/lib/uno/environments/remote/IThreadPool.java Tue Apr 29 19:11:53 2014
@@ -116,7 +116,7 @@ public interface IThreadPool {
 
 	/**
 	 * Destroys the thread pool and tries
-	 * to join all created threads immediatly.
+	 * to join all created threads immediately.
 	 */
 	public void destroy();
 }

Modified: openoffice/trunk/main/jurt/com/sun/star/lib/util/UrlToFileMapper.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/jurt/com/sun/star/lib/util/UrlToFileMapper.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/jurt/com/sun/star/lib/util/UrlToFileMapper.java (original)
+++ openoffice/trunk/main/jurt/com/sun/star/lib/util/UrlToFileMapper.java Tue Apr 29 19:11:53 2014
@@ -79,7 +79,7 @@ public final class UrlToFileMapper {
                                StringHelper.replace(url.getPath(), '+', "%2B")))
                 : null;
         } else {
-            // If java.net.URI is avaliable, do
+            // If java.net.URI is available, do
             //   URI uri = new URI(encodedUrl);
             //   try {
             //       return new File(uri);

Modified: openoffice/trunk/main/jurt/source/pipe/com_sun_star_lib_connections_pipe_PipeConnection.c
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/jurt/source/pipe/com_sun_star_lib_connections_pipe_PipeConnection.c?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/jurt/source/pipe/com_sun_star_lib_connections_pipe_PipeConnection.c (original)
+++ openoffice/trunk/main/jurt/source/pipe/com_sun_star_lib_connections_pipe_PipeConnection.c Tue Apr 29 19:11:53 2014
@@ -342,7 +342,7 @@ JNICALL Java_com_sun_star_lib_connection
 	enum {
 		START	= 0,
 		INMONITOR,
-		AQUIRED,
+		ACQUIRED,
 		GOTBUFFER
 	};
 
@@ -374,9 +374,9 @@ JNICALL Java_com_sun_star_lib_connection
         goto error;
     }
 
-    /* aquire pipe */
+    /* acquire pipe */
     osl_acquirePipe( npipe );
-    state = AQUIRED;
+    state = ACQUIRED;
 
     /* allocate a buffer */
     if ((nbuff = malloc(len)) == NULL)
@@ -424,7 +424,7 @@ JNICALL Java_com_sun_star_lib_connection
 
     /* done */
     free(nbuff);
-    if ( state >= AQUIRED )
+    if ( state >= ACQUIRED )
         osl_releasePipe( npipe );
 
     /* exit monitor */

Modified: openoffice/trunk/main/jvmfwk/inc/jvmfwk/framework.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/jvmfwk/inc/jvmfwk/framework.h?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/jvmfwk/inc/jvmfwk/framework.h (original)
+++ openoffice/trunk/main/jvmfwk/inc/jvmfwk/framework.h Tue Apr 29 19:11:53 2014
@@ -140,7 +140,7 @@ extern "C" {
     -env:UNO_JAVA_JFW_PLUGIN=file:\\solver\\bin\\sunjavaplugin.dll -register ....
     </p>
     <p>Additionall parameters for the Java VM can be provided. For every parameter
-    a seperate bootstrap parameter must be specified. The names are
+    a separate bootstrap parameter must be specified. The names are
     <code>UNO_JAVA_JFW_PARAMETER_X</code>, where X is 1,2, .. n. For example:</p>
     <p>
     regcomp -env:UNO_JAVA_JFW_PARAMETER_1=-Xdebug
@@ -311,7 +311,7 @@ void SAL_CALL jfw_freeJavaInfo(JavaInfo 
    <code>rtl_uString</code> members is determined
    by the respective comparison function (see
    <code>rtl::OUString::equals</code>).
-   Similiarly the equality of the <code>sal_Sequence</code> is
+   Similarly the equality of the <code>sal_Sequence</code> is
    also determined by a comparison
    function (see <code>rtl::ByteSequence::operator ==</code>). </p>
    <p>
@@ -330,8 +330,8 @@ sal_Bool SAL_CALL jfw_areEqualJavaInfo(
 /** determines if a Java Virtual Machine is already running.
     
     <p>As long as the the office and the JREs only support one
-    Virtual Machine per process the Java settings, particulary the
-    selected Java, are not effective immediatly after changing when
+    Virtual Machine per process the Java settings, particularly the
+    selected Java, are not effective immediately after changing when
     a VM has already been running. That is, if a JRE A was used to start
     a VM and then a JRE B is selected, then JRE B will only be used
     after a restart of the office.</p>
@@ -415,7 +415,7 @@ javaFrameworkError SAL_CALL jfw_isVMRunn
  */
 javaFrameworkError SAL_CALL jfw_findAndSelectJRE(JavaInfo **pInfo);
 
-/** provides information about all availabe JRE installations.
+/** provides information about all available JRE installations.
 
     <p>The function determines dynamically what JREs are available. It uses
     the plug-in libraries to provide lists of available <code>JavaInfo</code>

Modified: openoffice/trunk/main/jvmfwk/plugins/sunmajor/pluginlib/sunversion.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/jvmfwk/plugins/sunmajor/pluginlib/sunversion.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/jvmfwk/plugins/sunmajor/pluginlib/sunversion.cxx (original)
+++ openoffice/trunk/main/jvmfwk/plugins/sunmajor/pluginlib/sunversion.cxx Tue Apr 29 19:11:53 2014
@@ -71,12 +71,12 @@ bool SunVersion::init(const char *szVers
     if ( ! szVersion || strlen(szVersion) == 0)
         return false;
     
-    //first get the major,minor,maintainance
+    //first get the major,minor,maintenance
     const char * pLast = szVersion;
     const char * pCur = szVersion;
 	//pEnd point to the position after the last character
     const char * pEnd = szVersion + strlen(szVersion);
-    // 0 = major, 1 = minor, 2 = maintainance, 3 = update
+    // 0 = major, 1 = minor, 2 = maintenance, 3 = update
     int nPart = 0;
     // position within part beginning with 0
     int nPartPos = 0;
@@ -95,7 +95,7 @@ bool SunVersion::init(const char *szVers
         else if (
             ! (nPartPos == 0) // prevents: ".4.1", "..1", part must start with digit
             && (
-                //seperators after maintainance (1.4.1_01, 1.4.1-beta, or1.4.1
+                //seperators after maintenance (1.4.1_01, 1.4.1-beta, or1.4.1
                 ((pCur == pEnd || *pCur == '_' || *pCur == '-') && (nPart == 2 ))
                 ||
                 //separators between major-minor and minor-maintainance
@@ -268,7 +268,7 @@ bool SunVersion::operator > (const SunVe
     if( &ver == this)
         return false;
     
-    //compare major.minor.maintainance
+    //compare major.minor.maintenance
     for( int i= 0; i < 4; i ++)
     {
         // 1.4 > 1.3

Modified: openoffice/trunk/main/jvmfwk/plugins/sunmajor/pluginlib/util.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/jvmfwk/plugins/sunmajor/pluginlib/util.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/jvmfwk/plugins/sunmajor/pluginlib/util.cxx (original)
+++ openoffice/trunk/main/jvmfwk/plugins/sunmajor/pluginlib/util.cxx Tue Apr 29 19:11:53 2014
@@ -572,7 +572,7 @@ bool getJavaInfoFromRegistry(const wchar
                     // Get the path for the runtime lib
                     if(RegQueryValueExW(hKey, L"JavaHome", 0, &dwType, (unsigned char*) szTmpPath, &dwTmpPathLen) == ERROR_SUCCESS)
                     {
-                        // There can be several version entries refering with the same JavaHome,e.g 1.4 and 1.4.1
+                        // There can be several version entries referring with the same JavaHome,e.g 1.4 and 1.4.1
                         OUString usHome((sal_Unicode*) szTmpPath);
                         // check if there is already an entry with the same JavaHomeruntime lib
                         // if so, we use the one with the more accurate version

Modified: openoffice/trunk/main/jvmfwk/source/elements.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/jvmfwk/source/elements.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/jvmfwk/source/elements.cxx (original)
+++ openoffice/trunk/main/jvmfwk/source/elements.cxx Tue Apr 29 19:11:53 2014
@@ -756,7 +756,7 @@ jfw::FileStatus NodeJava::checkSettingsF
         {
             // This
             //function may be called multiple times when a java is started.
-            //If the expiretime is too small then we may loop because everytime
+            //If the expiretime is too small then we may loop because every time
             //the file is deleted and we need to search for a java again.
             if (INSTALL == m_layer)
             {

Modified: openoffice/trunk/main/jvmfwk/source/elements.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/jvmfwk/source/elements.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/jvmfwk/source/elements.hxx (original)
+++ openoffice/trunk/main/jvmfwk/source/elements.hxx Tue Apr 29 19:11:53 2014
@@ -128,7 +128,7 @@ private:
     /** creates settings file and fills it with default values.
 
         When this function is called then it creates the
-        settings file at the possition determined by the bootstrap parameters
+        settings file at the position determined by the bootstrap parameters
         (UNO_JAVA_JFW_USER_DATA, UNO_JAVA_JFW_SHARED_DATA,
         UNO_JAVA_JFW_INSTALL_DATA) and m_layer, unless the file already exists
         (see createSettingsDocument).
@@ -144,7 +144,7 @@ private:
     
     /** returns the system path to the data file which is to be used. The value
         depends on
-        the the member m_layer and the bootstrap paramters UNO_JAVA_JFW_USER_DATA,
+        the the member m_layer and the bootstrap parameters UNO_JAVA_JFW_USER_DATA,
         UNO_JAVA_JFW_SHARED_DATA and UNO_JAVA_JFW_INSTALL_DATA which this may be.
     */
     ::rtl::OString getSettingsPath() const;

Modified: openoffice/trunk/main/jvmfwk/source/fwkutil.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/jvmfwk/source/fwkutil.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/jvmfwk/source/fwkutil.hxx (original)
+++ openoffice/trunk/main/jvmfwk/source/fwkutil.hxx Tue Apr 29 19:11:53 2014
@@ -116,7 +116,7 @@ enum FileStatus
     one of the values of FileStatus.
     
     @exception
-    Errors occured during determining if the file exists
+    Errors occurred during determining if the file exists
  */
 FileStatus checkFileURL(const rtl::OUString & path);
 

Modified: openoffice/trunk/main/l10ntools/inc/wtranode.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/inc/wtranode.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/inc/wtranode.hxx (original)
+++ openoffice/trunk/main/l10ntools/inc/wtranode.hxx Tue Apr 29 19:11:53 2014
@@ -45,7 +45,7 @@ const BRANCH_T C_NR_OF_BRANCHES = 34;
 /**	@task
 	This is a node of the parsing-tree which implements the fuctionality of
 	class WordTransTree.
-	WordTransTree is dependant of this class, but NOT the other way!
+	WordTransTree is dependent of this class, but NOT the other way!
 **/
 class WTT_Node	// WordTransTree-Node
 {

Modified: openoffice/trunk/main/l10ntools/inc/wtratree.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/inc/wtratree.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/inc/wtratree.hxx (original)
+++ openoffice/trunk/main/l10ntools/inc/wtratree.hxx Tue Apr 29 19:11:53 2014
@@ -45,7 +45,7 @@ class WTT_Node;
 /**	@task
 	This class implements the functionality, that class WordTransformer
 	offers.
-	WordTransformer is dependant of this class, but NOT the other way!
+	WordTransformer is dependent of this class, but NOT the other way!
 **/
 class WordTransTree
 {
@@ -118,7 +118,7 @@ class WordTransTree
 
 		// Data which are valid only after a completed call to TransformNextToken()
 	E_Result			eCurResult;
-	u_char				cCurHotkey;            	// Letter wich is used as hotkey
+	u_char				cCurHotkey;            	// Letter which is used as hotkey
 	u_char				cCurHotkeySign;       	// Letter which is used to assign hotkey ('~'or '&') .
 };
 

Modified: openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/Convert.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/Convert.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/Convert.java (original)
+++ openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/Convert.java Tue Apr 29 19:11:53 2014
@@ -173,10 +173,10 @@ public class Convert {
                     OutputHandler.closeAll();
                 
                 } catch(Exception e){
-                    System.out.print("An EXCEPTION occured, please check your commad line settings \n"+e.getMessage());
+                    System.out.print("An EXCEPTION occurred, please check your commad line settings \n"+e.getMessage());
                     System.exit(-1);
                 }catch(Throwable t){
-                    System.out.print("A FATAL ERROR occured, please check your commad line settings \n"+t.getMessage());
+                    System.out.print("A FATAL ERROR occurred, please check your commad line settings \n"+t.getMessage());
                     System.exit(-1);
                 }
 
@@ -451,7 +451,7 @@ public class Convert {
                 OutputHandler.out("ERROR: "+e.getMessage());
                 System.exit(-1);
             } catch (Throwable t){
-                System.out.print("An Error occured while parsing the command line,\n please check your commad line settings.\n "+t.getMessage());
+                System.out.print("An Error occurred while parsing the command line,\n please check your commad line settings.\n "+t.getMessage());
                 System.exit(-1);
             }
 

Modified: openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/ConverterException.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/ConverterException.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/ConverterException.java (original)
+++ openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/ConverterException.java Tue Apr 29 19:11:53 2014
@@ -22,7 +22,7 @@
 
 /*
  * a simple exception
- * just to seperate 
+ * just to separate 
  * it from other
  * exceptions
  */

Modified: openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/FileMaker.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/FileMaker.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/FileMaker.java (original)
+++ openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/FileMaker.java Tue Apr 29 19:11:53 2014
@@ -41,7 +41,7 @@ import java.io.IOException;
 public final class FileMaker {
 
     /**
-     * Create a new file if overwriting is not alowed
+     * Create a new file if overwriting is not allowed
      * ask if existing files should be overwritten
      * 
      * @param fileName the files name to overwrite

Modified: openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/GSIWriter.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/GSIWriter.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/GSIWriter.java (original)
+++ openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/GSIWriter.java Tue Apr 29 19:11:53 2014
@@ -33,7 +33,7 @@ import com.sun.star.tooling.languageReso
  */
 public class GSIWriter  extends DataWriter {
     /**
-     * The seperator used to seperate GSI columns 
+     * The seperator used to separate GSI columns 
      */
     final String seperator=new String("($$)");
 
@@ -155,16 +155,16 @@ public class GSIWriter  extends DataWrit
         else {
             // put them together for output
             buffer.append(this.blockNr);
-            // seperate the fields with ($$)
+            // separate the fields with ($$)
             buffer.append(this.seperator);
             buffer.append(ResTypeResolver.getExternKey(resType));
-            // seperate the fields with ($$)
+            // separate the fields with ($$)
             buffer.append(this.seperator);
             buffer.append(this.sourceLanguage);
-            // seperate the fields with ($$)
+            // separate the fields with ($$)
             buffer.append(this.seperator);
             buffer.append("int");
-            // seperate the fields with ($$)
+            // separate the fields with ($$)
             buffer.append(this.seperator);
             buffer.append(outData.get(resString));
            
@@ -189,16 +189,16 @@ public class GSIWriter  extends DataWrit
         else {
             // put them together for output
             buffer.append(this.blockNr);
-            // seperate the fields with ($$)
+            // separate the fields with ($$)
             buffer.append(this.seperator);
             buffer.append(ResTypeResolver.getExternKey(resType));
-            // seperate the fields with ($$)
+            // separate the fields with ($$)
             buffer.append(this.seperator);
             buffer.append(this.targetLanguage);
-            // seperate the fields with ($$)
+            // separate the fields with ($$)
             buffer.append(this.seperator);
             buffer.append("ext");
-            // seperate the fields with ($$)
+            // separate the fields with ($$)
             buffer.append(this.seperator);
             buffer.append(outData.get(resString));
             

Modified: openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/GSIandSDFMerger.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/GSIandSDFMerger.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/GSIandSDFMerger.java (original)
+++ openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/GSIandSDFMerger.java Tue Apr 29 19:11:53 2014
@@ -137,7 +137,7 @@ public class GSIandSDFMerger extends SDF
                     }else{
 //                        skip=true;
 //                        
-//                    // we cant match this gsi block to the current sdf block
+//                    // we can't match this gsi block to the current sdf block
                       // try matching the next sdf block with this gsi line
                        dontLoadGSI=true;
                     }

Modified: openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/SDFReader.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/SDFReader.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/SDFReader.java (original)
+++ openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/SDFReader.java Tue Apr 29 19:11:53 2014
@@ -581,7 +581,7 @@ public class SDFReader extends DataReade
         if ((splitLine = line.split("\t")).length == 15)
             return splitLine;
         else
-            //an error occured
+            //an error occurred
             return null;
     }
 

Modified: openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/SDFWriter.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/SDFWriter.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/SDFWriter.java (original)
+++ openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/SDFWriter.java Tue Apr 29 19:11:53 2014
@@ -38,7 +38,7 @@ import java.util.Map;
  */
 public class SDFWriter  extends DataWriter {
     /**
-     * the seperator the seperate columns
+     * the seperator the separate columns
      */
     final String seperator=new String("\t");
     /**
@@ -109,7 +109,7 @@ public class SDFWriter  extends DataWrit
             // put them together for output
             buffer.append(outData.get(sourceLineNames[i]));
             if(i!=sourceLineNames.length-1) {
-                // seperate the fields with tab
+                // separate the fields with tab
                 buffer.append(seperator);
             }else{
                 // this line is full
@@ -125,7 +125,7 @@ public class SDFWriter  extends DataWrit
                 // put them together for output
                 buffer.append(outData.get(targetLineNames[i]));
                 if(i!=targetLineNames.length-1) {
-                    // seperate the fields with tab
+                    // separate the fields with tab
                     buffer.append(seperator);
                 }else{
                     // this line is full

Modified: openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/XLIFFWriter.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/XLIFFWriter.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/XLIFFWriter.java (original)
+++ openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/XLIFFWriter.java Tue Apr 29 19:11:53 2014
@@ -492,9 +492,9 @@ public class XLIFFWriter extends DataWri
 		return "<header></header>\n";
 	}
     /**
-     * Create the begining of the line holding the body tag of this XIFFFile
+     * Create the beginning of the line holding the body tag of this XIFFFile
      * 
-     * @return a string  with the begining of the body tag of this XIFFFile
+     * @return a string  with the beginning of the body tag of this XIFFFile
      */
 	private String openBodyTag() {
 		return "\t\t<body>\n";

Modified: openoffice/trunk/main/l10ntools/scripts/localize.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/scripts/localize.pl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/scripts/localize.pl (original)
+++ openoffice/trunk/main/l10ntools/scripts/localize.pl Tue Apr 29 19:11:53 2014
@@ -1036,7 +1036,7 @@ sub usage{
     print STDERR "    -f <sdffile>    To split a big SDF file into particles\n";
     print STDERR "       <outputfile> To collect and join all particles to one big file\n";
     print STDERR "    -s <sourceroot> Path to the modules, if no \$SRC_ROOT is set\n";
-    print STDERR "    -l ( all | <isocode> | <isocode>=fallback ) comma seperated languages\n";
+    print STDERR "    -l ( all | <isocode> | <isocode>=fallback ) comma separated languages\n";
     print STDERR "    -d              Use default date in extracted sdf file\n";
     print STDERR "    -c              Create needed directories\n";
     print STDERR "    -g              Sort sdf file before mergeing\n";

Modified: openoffice/trunk/main/l10ntools/scripts/localize_old.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/scripts/localize_old.pl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/scripts/localize_old.pl (original)
+++ openoffice/trunk/main/l10ntools/scripts/localize_old.pl Tue Apr 29 19:11:53 2014
@@ -1031,7 +1031,7 @@ sub usage{
     print STDERR "    -f <sdffile>    To split a big SDF file into particles\n";
     print STDERR "       <outputfile> To collect and join all particles to one big file\n";
     print STDERR "    -s <sourceroot> Path to the modules, if no \$SRC_ROOT is set\n";
-    print STDERR "    -l ( all | <isocode> | <isocode>=fallback ) comma seperated languages\n";
+    print STDERR "    -l ( all | <isocode> | <isocode>=fallback ) comma separated languages\n";
     print STDERR "    -d              Use default date in extracted sdf file\n";
     print STDERR "    -v              Verbose\n";
     print STDERR "\nExample:\n";

Modified: openoffice/trunk/main/l10ntools/source/cfgmerge.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/cfgmerge.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/cfgmerge.cxx (original)
+++ openoffice/trunk/main/l10ntools/source/cfgmerge.cxx Tue Apr 29 19:11:53 2014
@@ -246,7 +246,7 @@ extern FILE *GetCfgFile()
 			aEntry += DirEntry( sPrjRoot );
 			ByteString sPrjEntry( aEntry.GetFull(), RTL_TEXTENCODING_ASCII_US );
 
-			// create file name, beginnig with project root
+			// create file name, beginning with project root
 			// (e.g.: source\ui\src\menue.src)
 //			printf("sFullEntry = %s\n",sFullEntry.GetBuffer());
             sActFileName = sFullEntry.Copy( sPrjEntry.Len() + 1 );

Modified: openoffice/trunk/main/l10ntools/source/export.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/export.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/export.cxx (original)
+++ openoffice/trunk/main/l10ntools/source/export.cxx Tue Apr 29 19:11:53 2014
@@ -263,7 +263,7 @@ extern FILE *GetNextFile()
 			aEntry += DirEntry( sPrjRoot );
 			ByteString sPrjEntry( aEntry.GetFull(), RTL_TEXTENCODING_ASCII_US );
 
-			// create file name, beginnig with project root
+			// create file name, beginning with project root
 			// (e.g.: source\ui\src\menue.src)
 			sActFileName = sFullEntry.Copy( sPrjEntry.Len() + 1 );
 

Modified: openoffice/trunk/main/l10ntools/source/filter/merge/FCFGMerge.cfg
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/filter/merge/FCFGMerge.cfg?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/filter/merge/FCFGMerge.cfg (original)
+++ openoffice/trunk/main/l10ntools/source/filter/merge/FCFGMerge.cfg Tue Apr 29 19:11:53 2014
@@ -32,7 +32,7 @@
 loglevel = 2
 
 #************************************************
-# This extension is used for all XML files. It doesnt
+# This extension is used for all XML files. It doesn't
 # matter if its used for reading fragments or writing
 # XML packages.
 # Must be given without any additional signes like "."
@@ -44,7 +44,7 @@ loglevel = 2
 extension_xcu=xcu
 
 #************************************************
-# This extension is used for all Package files. It doesnt
+# This extension is used for all Package files. It doesn't
 # matter if its used for reading such files or writing
 # it.
 # Must be given without any additional signes like "."
@@ -91,7 +91,7 @@ subdir_contenthandlers 	= contenthandler
 #************************************************
 # This delimiter is used to split every
 # item list of the package configuration files
-# (which are temp. created  by the make proccess)
+# (which are temp. created  by the make process)
 # into its tokens.
 #
 # [REQUIRED]

Modified: openoffice/trunk/main/l10ntools/source/filter/merge/FCFGMerge.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/filter/merge/FCFGMerge.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/filter/merge/FCFGMerge.java (original)
+++ openoffice/trunk/main/l10ntools/source/filter/merge/FCFGMerge.java Tue Apr 29 19:11:53 2014
@@ -115,7 +115,7 @@ public class FCFGMerge
         sOut.append("parameters:\n"                                                 );
         sOut.append("\tcfg=<file name>\n"                                           );
         sOut.append("\t\tmust point to a system file, which contains\n"             );
-        sOut.append("\t\tall neccessary configuration data for the merge process.\n");
+        sOut.append("\t\tall necessary configuration data for the merge process.\n");
         sOut.append("\n\tFurther cou can specify every parameter allowed in the\n"  );
         sOut.append("\n\tconfig file as command line parameter too, to overwrite\n" );
         sOut.append("\n\tthe value from the file.\n"                                );

Modified: openoffice/trunk/main/l10ntools/source/filter/merge/Merger.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/filter/merge/Merger.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/filter/merge/Merger.java (original)
+++ openoffice/trunk/main/l10ntools/source/filter/merge/Merger.java Tue Apr 29 19:11:53 2014
@@ -199,7 +199,7 @@ public class Merger
                 m_aCfg.getString (PROP_XMLPACKAGE         ),
                 m_aCfg.getBoolean(PROP_LANGUAGEPACK, false)));
 
-        // counts all transfered fragments
+        // counts all transferred fragments
         // Can be used later to decide, if a generated package file
         // contains "nothing"!
         int nItemCount = 0;
@@ -307,7 +307,7 @@ public class Merger
 
         // special mode for generating language packs.
         // In such case we must live with some missing fragment files.
-        // Reason behind; Not all filters are realy localized.
+        // Reason behind; Not all filters are really localized.
         // But we dont use a different fragment list. We try to locate
         // any fragment file in its language-pack version ...
         boolean bHandleLanguagePacks = m_aCfg.getBoolean(PROP_LANGUAGEPACK, false);
@@ -340,7 +340,7 @@ public class Merger
             }
 
             // copy file content of original fragment
-            // Note: A FileNotFoundException will be thrown automaticly by the
+            // Note: A FileNotFoundException will be thrown automatically by the
             // used reader objects. Let it break this method too. Our calli is interested
             // on such errors :-)
             m_aLog.setDetailedInfo("merge fragment \""+aFragment.getPath()+"\" ...");

Modified: openoffice/trunk/main/l10ntools/source/filter/utils/Cache.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/filter/utils/Cache.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/filter/utils/ConfigHelper.java (original)
+++ openoffice/trunk/main/l10ntools/source/filter/utils/ConfigHelper.java Tue Apr 29 19:11:53 2014
@@ -66,7 +66,7 @@ public class ConfigHelper extends java.u
      *
      *  @throws [Exception]
      *          in case the command line contains an unknown
-     *          schema for specifiying parameters or the
+     *          schema for specifying parameters or the
      *          specified property file does not exists
      *          or seem to be corrupted.
      */
@@ -245,7 +245,7 @@ public class ConfigHelper extends java.u
      *
      *  @param  bTrim
      *          if its set to true, trailing and leading whitespace
-     *          characters will be ommited.
+     *          characters will be omitted.
      *
      *  @param  bDecode
      *          if its set to TRUE all liste items will be

Modified: openoffice/trunk/main/l10ntools/source/filter/utils/FileHelper.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/filter/utils/FileHelper.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/filter/utils/FileHelper.java (original)
+++ openoffice/trunk/main/l10ntools/source/filter/utils/FileHelper.java Tue Apr 29 19:11:53 2014
@@ -34,7 +34,7 @@ import java.util.*;
 
 /**
  * It collects some static helper functons to handle file system specific problems.
- * Sometimes it's neccessary to convert URL from/to system pathes;
+ * Sometimes it's necessary to convert URL from/to system paths;
  * or from string notation to structural versions (e.g. com.sun.star.util.URL).
  * And sometimes java had another notation then the office it has.
  * Further it provides functionality to work easiear with the java.io.File class of java.
@@ -47,7 +47,7 @@ public class FileHelper
 
     /**
      * Because the office need URLs for loading/saving documents
-     * we must convert used system pathes.
+     * we must convert used system paths.
      * And java use another notation for file URLs ... correct it.
      *
      * @param aSystemPath
@@ -92,7 +92,7 @@ public class FileHelper
 
     /**
      * The same as getFileURLFromSystemPath() before but uses string parameter instead
-     * of a java.io.File type. It exist to supress converting of neccessary parameters in the
+     * of a java.io.File type. It exist to suppress converting of necessary parameters in the
      * outside code. But of course getFileURLFromSystemPath(File) will be a little bit faster
      * then this method ...
      *
@@ -160,7 +160,7 @@ public class FileHelper
 
     /**
      * The same as getURLWithProtocolFromSystemPath() before but uses string parameter instead
-     * of a java.io.File types. It exist to supress converting of neccessary parameters in the
+     * of a java.io.File types. It exist to suppress converting of necessary parameters in the
      * outside code. But of course getURLWithProtocolFromSystemPath(File,File,String) will be
      * a little bit faster then this method ...
      *

Modified: openoffice/trunk/main/l10ntools/source/filter/utils/XMLHelper.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/filter/utils/XMLHelper.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/filter/utils/XMLHelper.java (original)
+++ openoffice/trunk/main/l10ntools/source/filter/utils/XMLHelper.java Tue Apr 29 19:11:53 2014
@@ -33,7 +33,7 @@ import java.io.*;
 
 /**
  *  It provides some constant values and some static helper routines
- *  which are neccessary to work with a xml file - especialy
+ *  which are necessary to work with a xml file - especially
  *  the filter configuration.
  *
  *
@@ -92,8 +92,8 @@ public class XMLHelper
     private static final java.lang.String[] DELIMS = {" ", ",", ";", ".", ":", "-", "_", "#", "'", "+", "*", "~", "=", "?"};
 
     /** index of the default separator inside list DELIMS.
-     *  Its neccessary to know such default separator; because it can
-     *  be supressed as xml attribute of the corresponding value tag. */
+     *  Its necessary to know such default separator; because it can
+     *  be suppressed as xml attribute of the corresponding value tag. */
     private static final int DEFAULT_SEPARATOR = 0;
 
     //___________________________________________
@@ -102,7 +102,7 @@ public class XMLHelper
      *  return a property set of all found sub nodes.
      *
      *  Such properties are organized as [name, value] pairs.
-     *  The type of a xml node will be detected automaticly.
+     *  The type of a xml node will be detected automatically.
      *  Following types are supported:
      *      xs:int          => java.lang.Integer
      *      xs:bool         => java.lang.Boolean
@@ -291,7 +291,7 @@ public class XMLHelper
      *          the xml string representation.
      *
      *  @throws [java.lang.Exception]
-     *          if anything during convertion fill fail.
+     *          if anything during conversion fill fail.
      */
     public static java.lang.String convertPropSetToXML(java.util.HashMap aPropSet   ,
                                                        int               nPrettyTabs)
@@ -386,7 +386,7 @@ public class XMLHelper
      *          the xml string representation.
      *
      *  @throws [java.lang.Exception]
-     *          if anything during convertion fill fail.
+     *          if anything during conversion fill fail.
      */
     private static java.lang.String convertSimpleObjectToXML(java.lang.String sName      ,
                                                              java.lang.Object aValue     ,
@@ -454,7 +454,7 @@ public class XMLHelper
      *          the xml string representation.
      *
      *  @throws [java.lang.Exception]
-     *          if anything during convertion fill fail.
+     *          if anything during conversion fill fail.
      */
     private static java.lang.String convertListToXML(java.lang.String sName      ,
                                                      java.util.Vector aValue     ,
@@ -498,7 +498,7 @@ public class XMLHelper
             sValue = encodeHTMLSigns(sValue);
 
             // append item with default separator, which isn a valid separator at all
-            // But supress adding of the separator if last element is reached.
+            // But suppress adding of the separator if last element is reached.
             sValBuff.append(sValue);
             if (i<(c-1))
                 sValBuff.append("\n");
@@ -559,7 +559,7 @@ public class XMLHelper
      *          the xml string representation.
      *
      *  @throws [java.lang.Exception]
-     *          if anything during convertion fill fail.
+     *          if anything during conversion fill fail.
      */
     private static java.lang.String convertLocalizedValueToXML(java.lang.String  sName      ,
                                                                java.util.HashMap aValue     ,
@@ -570,7 +570,7 @@ public class XMLHelper
 
         int c = aValue.size();
         if (c < 1)
-            throw new java.lang.Exception("Cant detect type of localized values. Because the given list is empty.");
+            throw new java.lang.Exception("Can't detect type of localized values. Because the given list is empty.");
 
         for (int t=0; t<nPrettyTabs; ++t)
             sXML.append("\t");
@@ -644,7 +644,7 @@ public class XMLHelper
             return null;
         }
 
-        // may it supports attributes in general ... but doesn't have anyone realy.
+        // may it supports attributes in general ... but doesn't have anyone really.
         org.w3c.dom.NamedNodeMap lAttribs = aNode.getAttributes();
         if (lAttribs==null)
         {

Modified: openoffice/trunk/main/l10ntools/source/help/HelpLinker.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/help/HelpLinker.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/help/HelpLinker.cxx (original)
+++ openoffice/trunk/main/l10ntools/source/help/HelpLinker.cxx Tue Apr 29 19:11:53 2014
@@ -865,7 +865,7 @@ void HelpLinker::main( std::vector<std::
     {
         //No extension mode and extension mode using commandline
         //!extsource.empty indicates extension mode using commandline
-        // -idxcaption paramter is required
+        // -idxcaption parameter is required
         std::stringstream aStrStream;
         aStrStream << "no index caption stylesheet given" << std::endl;
         throw HelpProcessingException( HELPPROCESSING_GENERAL_ERROR, aStrStream.str() );
@@ -889,7 +889,7 @@ void HelpLinker::main( std::vector<std::
     {
         //No extension mode and extension mode using commandline
         //!extsource.empty indicates extension mode using commandline
-        // -idxcontent paramter is required
+        // -idxcontent parameter is required
         std::stringstream aStrStream;
         aStrStream << "no index content stylesheet given" << std::endl;
         throw HelpProcessingException( HELPPROCESSING_GENERAL_ERROR, aStrStream.str() );

Modified: openoffice/trunk/main/l10ntools/source/merge.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/merge.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/merge.cxx (original)
+++ openoffice/trunk/main/l10ntools/source/merge.cxx Tue Apr 29 19:11:53 2014
@@ -361,7 +361,7 @@ void MergeDataFile::InsertEntry(
         pData->Insert( rPFO , pFEntrys );
     }
 
-    // finaly insert the cur string
+    // finally insert the cur string
     pFEntrys->InsertEntry( nLANG , rTEXT, rQHTEXT, rTITLE );
 }
 

Modified: openoffice/trunk/main/l10ntools/source/tagtest.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/tagtest.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/tagtest.cxx (original)
+++ openoffice/trunk/main/l10ntools/source/tagtest.cxx Tue Apr 29 19:11:53 2014
@@ -1246,7 +1246,7 @@ void TokenParser::TagRef()
     					match( aTag, TAG_ENDGRAPHIC );
                     else
     					match( aTag, TAG_VERSIONEND );
-                    // don't reset since alowed only once per paragraph
+                    // don't reset since allowed only once per paragraph
 					// RESET_FLAG( nActiveRefTypes, TAG_NOGROUP( aThisToken ) );
 				}
 				else

Modified: openoffice/trunk/main/l10ntools/source/xmlparse.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/xmlparse.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/xmlparse.cxx (original)
+++ openoffice/trunk/main/l10ntools/source/xmlparse.cxx Tue Apr 29 19:11:53 2014
@@ -1246,7 +1246,7 @@ XMLFile *SimpleXMLParser::Execute( SvMem
 	if ( pXMLFile->GetName().Len()) {
 		aErrorInformation.sMessage = String::CreateFromAscii( "File " );
 		aErrorInformation.sMessage += pXMLFile->GetName();
-		aErrorInformation.sMessage += String::CreateFromAscii( " parsed succesfully" );
+		aErrorInformation.sMessage += String::CreateFromAscii( " parsed successfully" );
 	}
 	else
 		aErrorInformation.sMessage = String::CreateFromAscii( "XML-File parsed successfully" );

Modified: openoffice/trunk/main/l10ntools/source/xrmmerge.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/xrmmerge.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/xrmmerge.cxx (original)
+++ openoffice/trunk/main/l10ntools/source/xrmmerge.cxx Tue Apr 29 19:11:53 2014
@@ -235,7 +235,7 @@ extern FILE *GetXrmFile()
 			aEntry += DirEntry( sPrjRoot );
 			ByteString sPrjEntry( aEntry.GetFull(), RTL_TEXTENCODING_ASCII_US );
 
-			// create file name, beginnig with project root
+			// create file name, beginning with project root
 			// (e.g.: source\ui\src\menue.src)
 			sActFileName = sFullEntry.Copy( sPrjEntry.Len() + 1 );
 

Modified: openoffice/trunk/main/libtextcat/libtextcat-2.2.patch
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/libtextcat/libtextcat-2.2.patch?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/libtextcat/libtextcat-2.2.patch (original)
+++ openoffice/trunk/main/libtextcat/libtextcat-2.2.patch Tue Apr 29 19:11:53 2014
@@ -726,7 +726,7 @@
 +	while(1) {
  
 -		const char *q = p;
-+     const char *q = &p[pointer];   /*[modified] previously p++ above (for(;;p++)) now, it's pointer wich is increased so we have to get the new pointer on the buffer*/
++     const char *q = &p[pointer];   /*[modified] previously p++ above (for(;;p++)) now, it's pointer which is increased so we have to get the new pointer on the buffer*/
  		char *m = n;
  
  		/*** First char may be an underscore ***/
@@ -759,7 +759,7 @@
  			}
  		}
 +
-+  pointer = nextcharstart(p,pointer);   /*[modified] p[pointer] must point on the next start of symbol, but whith utf next start is not surely next char*/
++  pointer = nextcharstart(p,pointer);   /*[modified] p[pointer] must point on the next start of symbol, but with utf next start is not surely next char*/
  	}
  	return;
  }
@@ -1088,8 +1088,8 @@
 +}
 +
 +/**
-+ * Originaly this function had only one parameter (conffile) it has been modified since OOo use
-+ * Basicaly prefix is the directory path where fingerprints are stored
++ * Originally this function had only one parameter (conffile) it has been modified since OOo use
++ * Basically prefix is the directory path where fingerprints are stored
 + */
 +extern void *special_textcat_Init( const char *conffile, const char *prefix )
  {
@@ -1208,8 +1208,8 @@
  extern void *textcat_Init( const char *conffile );
  
  /**
-+ * Originaly this function had only one parameter (conffile) it has been modified since OOo must be able to load alternativ DB
-+ * Basicaly prefix is the directory path where fingerprints are stored
++ * Originally this function had only one parameter (conffile) it has been modified since OOo must be able to load alternativ DB
++ * Basically prefix is the directory path where fingerprints are stored
 + */
 +extern void *special_textcat_Init( const char *conffile, const char *prefix );
 +
@@ -1284,7 +1284,7 @@
 +        ++pointer;
 +    }
 +    }
-+    if(str[pointer]){   /*finaly, if we are not on the \0 character, we jump to the next character*/
++    if(str[pointer]){   /*finally, if we are not on the \0 character, we jump to the next character*/
 +        ++pointer;
 +    }
 +    return pointer;
@@ -1419,14 +1419,14 @@
 +
 +/*
 + * Is used to jump to the next start of char
-+ * of course it's only usefull when encoding is utf-8
++ * of course it's only useful when encoding is utf-8
 + * This function have been added by Jocelyn Merand to use libtextcat in OOo
 + */
 +int nextcharstart(const char *str, int position);
 +
 +
 +/*Copy the char in str to dest
-+ * of course it's only usefull when encoding is utf8 and the symbol is encoded with more than 1 char
++ * of course it's only useful when encoding is utf8 and the symbol is encoded with more than 1 char
 + * return the number of char jumped
 + * This function have been added by Jocelyn Merand to use libtextcat in OOo
 + */
@@ -1434,14 +1434,14 @@
 +
 +
 +/* checks if n-gram lex is a prefix of key and of length len
-+* if _UTF8_ is defined, it uses escap characters and len is not realy the length of lex
++* if _UTF8_ is defined, it uses escap characters and len is not really the length of lex
 +* in this case, len is the number of utf-8 char strlen("€") == 3 but len == 1
 +*/
 +int issame( char *lex, char *key, int len );
 +
 +
 +/* Counts the number of characters
-+* if _UTF8_ is defined, it uses escap characters and the result is not realy the length of str
++* if _UTF8_ is defined, it uses escap characters and the result is not really the length of str
 +* in this case, the result is the number of utf-8 char strlen("€") == 3 but utfstrlen("€") == 1
 +*/
 +#ifdef __cplusplus

Modified: openoffice/trunk/main/libxml2/libxml2-long-path.patch
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/libxml2/libxml2-long-path.patch?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/libxml2/libxml2-long-path.patch (original)
+++ openoffice/trunk/main/libxml2/libxml2-long-path.patch Tue Apr 29 19:11:53 2014
@@ -8,7 +8,7 @@
 +#if defined(_WIN32) 	
 +	//We must not change the backslashes to slashes if the the path starts with
 +	// \\?\
-+	//Those pathes can be up to 32k characters long.
++	//Those paths can be up to 32k characters long.
 +	len = xmlStrlen(path);
 +	if ((len > 3) && (path[0] == '\\') && (path[1] == '\\') && (path[2] == '?') && (path[3] == '\\') )
 +		return xmlStrdup((const xmlChar *) path);

Modified: openoffice/trunk/main/libxmlsec/xmlsec1-customkeymanage.patch
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/libxmlsec/xmlsec1-customkeymanage.patch?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/libxmlsec/xmlsec1-customkeymanage.patch (original)
+++ openoffice/trunk/main/libxmlsec/xmlsec1-customkeymanage.patch Tue Apr 29 19:11:53 2014
@@ -796,7 +796,7 @@
 +
 +/**
 + * xmlSecNssAppliedKeysMngrCreate:
-+ * @slot:			array of pointers to NSS PKCS#11 slot infomation.
++ * @slot:			array of pointers to NSS PKCS#11 slot information.
 + * @cSlots:			number of slots in the array
 + * @handler:		the pointer to NSS certificate database.
 + *
@@ -4386,7 +4386,7 @@
 + * every eligibl slot in the list.
 + *
 + * When try to find a slot for a particular mechanism, the slot bound with
-+ * avaliable mechanism will be looked up firstly.
++ * available mechanism will be looked up firstly.
 + */
 +#include "globals.h"
 +#include <string.h>

Modified: openoffice/trunk/main/libxmlsec/xmlsec1-noverify.patch
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/libxmlsec/xmlsec1-noverify.patch?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/libxmlsec/xmlsec1-noverify.patch (original)
+++ openoffice/trunk/main/libxmlsec/xmlsec1-noverify.patch Tue Apr 29 19:11:53 2014
@@ -8,7 +8,7 @@
 -            return(cert);
 -        }
 +        /* JL: OpenOffice.org implements its own certificate verification routine. 
-+           The goal is to seperate validation of the signature
++           The goal is to separate validation of the signature
 +           and the certificate. For example, OOo could show that the document signature is valid,
 +           but the certificate could not be verified. If we do not prevent the verification of
 +           the certificate by libxmlsec and the verification fails, then the XML signature will not be 
@@ -36,7 +36,7 @@
 +
 +	/*
 +      JL: OpenOffice.org implements its own certificate verification routine. 
-+      The goal is to seperate validation of the signature
++      The goal is to separate validation of the signature
 +      and the certificate. For example, OOo could show that the document signature is valid,
 +      but the certificate could not be verified. If we do not prevent the verification of
 +      the certificate by libxmlsec and the verification fails, then the XML signature may not be 

Modified: openoffice/trunk/main/lingucomponent/source/hyphenator/altlinuxhyph/hyphen/hyphenimp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/lingucomponent/source/hyphenator/altlinuxhyph/hyphen/hyphenimp.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/lingucomponent/source/hyphenator/altlinuxhyph/hyphen/hyphenimp.cxx (original)
+++ openoffice/trunk/main/lingucomponent/source/hyphenator/altlinuxhyph/hyphen/hyphenimp.cxx Tue Apr 29 19:11:53 2014
@@ -191,7 +191,7 @@ Sequence< Locale > SAL_CALL Hyphenator::
                 aSuppLocales[k++] = aTmp;
             }
 
-            //! For each dictionary and each locale we need a seperate entry.
+            //! For each dictionary and each locale we need a separate entry.
             //! If this results in more than one dictionary per locale than (for now)
 			//! it is undefined which dictionary gets used.
 			//! In the future the implementation should support using several dictionaries

Modified: openoffice/trunk/main/lingucomponent/source/languageguessing/simpleguesser.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/lingucomponent/source/languageguessing/simpleguesser.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/lingucomponent/source/languageguessing/simpleguesser.cxx (original)
+++ openoffice/trunk/main/lingucomponent/source/languageguessing/simpleguesser.cxx Tue Apr 29 19:11:53 2014
@@ -158,7 +158,7 @@ Guess SimpleGuesser::GuessPrimaryLanguag
     }
 }
 /**
- * Is used to know wich language is available, unavailable or both
+ * Is used to know which language is available, unavailable or both
  * when mask = 0xF0, return only Available
  * when mask = 0x0F, return only Unavailable
  * when mask = 0xFF, return both Available and Unavailable

Modified: openoffice/trunk/main/lingucomponent/source/spellcheck/macosxspell/macspellimp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/lingucomponent/source/spellcheck/macosxspell/macspellimp.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/lingucomponent/source/spellcheck/macosxspell/macspellimp.cxx (original)
+++ openoffice/trunk/main/lingucomponent/source/spellcheck/macosxspell/macspellimp.cxx Tue Apr 29 19:11:53 2014
@@ -311,7 +311,7 @@ sal_Bool SAL_CALL
 	// These are be the default values set in the SN_LINGU_PROPERTIES
 	// PropertySet which are overridden by the supplied ones from the
 	// last argument.
-	// You'll probably like to use a simplier solution than the provided
+	// You'll probably like to use a simpler solution than the provided
 	// one using the PropertyHelper_Spell.
 
 	PropertyHelper_Spell &rHelper = GetPropHelper();

Modified: openoffice/trunk/main/lingucomponent/source/spellcheck/spell/sspellimp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/lingucomponent/source/spellcheck/spell/sspellimp.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/lingucomponent/source/spellcheck/spell/sspellimp.cxx (original)
+++ openoffice/trunk/main/lingucomponent/source/spellcheck/spell/sspellimp.cxx Tue Apr 29 19:11:53 2014
@@ -184,7 +184,7 @@ Sequence< Locale > SAL_CALL SpellChecker
                 aSuppLocales[k++] = aTmp;
             }
 
-            //! For each dictionary and each locale we need a seperate entry.
+            //! For each dictionary and each locale we need a separate entry.
             //! If this results in more than one dictionary per locale than (for now)
 			//! it is undefined which dictionary gets used.
 			//! In the future the implementation should support using several dictionaries
@@ -379,7 +379,7 @@ sal_Bool SAL_CALL SpellChecker::isValid(
 	// These are be the default values set in the SN_LINGU_PROPERTIES
 	// PropertySet which are overridden by the supplied ones from the
 	// last argument.
-	// You'll probably like to use a simplier solution than the provided
+	// You'll probably like to use a simpler solution than the provided
 	// one using the PropertyHelper_Spell.
 
 	PropertyHelper_Spell &rHelper = GetPropHelper();

Modified: openoffice/trunk/main/lingucomponent/source/thesaurus/libnth/nthesimp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/lingucomponent/source/thesaurus/libnth/nthesimp.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/lingucomponent/source/thesaurus/libnth/nthesimp.cxx (original)
+++ openoffice/trunk/main/lingucomponent/source/thesaurus/libnth/nthesimp.cxx Tue Apr 29 19:11:53 2014
@@ -212,7 +212,7 @@ Sequence< Locale > SAL_CALL Thesaurus::g
                 aSuppLocales[k++] = aTmp;
             }
 
-            //! For each dictionary and each locale we need a seperate entry.
+            //! For each dictionary and each locale we need a separate entry.
             //! If this results in more than one dictionary per locale than (for now)
 			//! it is undefined which dictionary gets used.
 			//! In the future the implementation should support using several dictionaries

Modified: openoffice/trunk/main/linguistic/inc/linguistic/misc.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/linguistic/inc/linguistic/misc.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/linguistic/inc/linguistic/misc.hxx (original)
+++ openoffice/trunk/main/linguistic/inc/linguistic/misc.hxx Tue Apr 29 19:11:53 2014
@@ -161,7 +161,7 @@ String  GetModulePath( SvtPathOptions::P
 String  GetWritableDictionaryURL( const String &rDicName );
 
 // looks for the specified file in the list of paths.
-// In case of multiple occurences only the first found is returned.
+// In case of multiple occurrences only the first found is returned.
 String     SearchFileInPaths( const String &rFile, const ::com::sun::star::uno::Sequence< ::rtl::OUString > &rPaths );
 
 

Modified: openoffice/trunk/main/linguistic/qa/complex/linguistic/HangulHanjaConversion.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/linguistic/qa/complex/linguistic/HangulHanjaConversion.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/linguistic/qa/complex/linguistic/HangulHanjaConversion.java (original)
+++ openoffice/trunk/main/linguistic/qa/complex/linguistic/HangulHanjaConversion.java Tue Apr 29 19:11:53 2014
@@ -84,7 +84,7 @@ public class HangulHanjaConversion {
 
         boolean bList = checkXConversionDictionaryList(
                                 ConversionDictionaryList);
-        assertTrue("XConversionDictionaryList doesnt work as expected", bList);
+        assertTrue("XConversionDictionaryList doesn't work as expected", bList);
     }
 
     private boolean checkXConversionDictionaryList(Object list) {

Modified: openoffice/trunk/main/linguistic/source/convdicxml.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/linguistic/source/convdicxml.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/linguistic/source/convdicxml.cxx (original)
+++ openoffice/trunk/main/linguistic/source/convdicxml.cxx Tue Apr 29 19:11:53 2014
@@ -373,7 +373,7 @@ sal_uInt32 ConvDicXMLExport::exportDoc( 
 
 void ConvDicXMLExport::_ExportContent()
 {
-    // aquire sorted list of all keys
+    // acquire sorted list of all keys
     ConvMapKeySet   aKeySet;
     ConvMap::iterator aIt;
     for (aIt = rDic.aFromLeft.begin();  aIt != rDic.aFromLeft.end();  ++aIt)
--- openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/PropertySet.java (original)
+++ openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/PropertySet.java Tue Apr 29 19:11:53 2014
@@ -404,7 +404,7 @@ XMultiPropertySet
     
     //XPropertySet ----------------------------------------------------
     synchronized public void removePropertyChangeListener(String propName, XPropertyChangeListener listener) throws UnknownPropertyException, WrappedTargetException
-    {	// all listeners are automaticly released in a dispose call
+    {	// all listeners are automatically released in a dispose call
         if (!bInDispose && !bDisposed)
         {
             if (propName.length() > 0)
@@ -421,7 +421,7 @@ XMultiPropertySet
 
     //XPropertySet ----------------------------------------------------
     synchronized public void removeVetoableChangeListener(String propName, XVetoableChangeListener listener) throws UnknownPropertyException, WrappedTargetException
-    {// all listeners are automaticly released in a dispose call
+    {// all listeners are automatically released in a dispose call
         if (!bInDispose && !bDisposed)
         {
             if (propName.length() > 0)
@@ -613,7 +613,7 @@ XMultiPropertySet
      *  @return true - Conversion was successful. <em>newVal</em> contains a valid value for the property. false - 
      *  conversion failed for some reason.
      *  @throws com.sun.star.lang.IllegalArgumentException The value provided is unfit for the property.
-     *  @throws com.sun.star.lang.WrappedTargetException - An exception occured during the conversion, that is to be made known 
+     *  @throws com.sun.star.lang.WrappedTargetException - An exception occurred during the conversion, that is to be made known 
      *  to the caller.
      */
     protected boolean convertPropertyValue(Property property, Object[] newVal, Object[]curVal,  Object setVal)
@@ -795,7 +795,7 @@ XMultiPropertySet
      *  @param property the property for which the new value is set
      *  @param value the new value for the property.
      *  @throws com.sun.star.lang.WrappedTargetException An exception, which has to be made known to the caller,
-     *  occured during the setting of the value.
+     *  occurred during the setting of the value.
      */
     protected void setPropertyValueNoBroadcast(Property property, Object newVal)
     throws WrappedTargetException
@@ -866,7 +866,7 @@ XMultiPropertySet
      *  a XVetoableChangeListener is meant. For XPropertyChangeListener and XPropertiesChangeListener
      *  it is to be set to false. 
      * 
-     * @param properties	Properties wich will be or have been affected.
+     * @param properties	Properties which will be or have been affected.
      * @param newValues	the new values of the properties.
      * @param oldValues	the old values of the properties.
      * @param bVetoable true means fire to VetoableChangeListener, false means fire to
@@ -1054,7 +1054,7 @@ XMultiPropertySet
         listenerContainer.removeInterface(XPropertiesChangeListener.class, xPropertiesChangeListener);
     }
     // XMultiPropertySet -----------------------------------------------------------------------------------  
-    /** If the array of property names containes an unknown property then it will be ignored.
+    /** If the array of property names contains an unknown property then it will be ignored.
      */
     public void setPropertyValues(String[] propNames, Object[] values) throws PropertyVetoException, com.sun.star.lang.IllegalArgumentException, com.sun.star.lang.WrappedTargetException
     {

Modified: openoffice/trunk/main/javaunohelper/test/com/sun/star/comp/helper/SharedLibraryLoader_Test.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/javaunohelper/test/com/sun/star/comp/helper/SharedLibraryLoader_Test.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/filter/utils/Cache.java (original)
+++ openoffice/trunk/main/l10ntools/source/filter/utils/Cache.java Tue Apr 29 19:11:53 2014
@@ -67,7 +67,7 @@ public class Cache
     public static final int FORMAT_60 = 0;
 
     /** identify the configuration format of an office 6.y.
      *  Properties are realy xml tags again. */
     public static final int FORMAT_6Y = 1;
 
     /** identify the configuration format which is used inside
@@ -336,7 +336,7 @@ public class Cache
      *
      *  @param  aXML
      *          must be a system file of a suitable XML file, which
-     *          include all neccessary type/filter items.
+     *          include all necessary type/filter items.
      *
      *  @param  nFormat
      *          identifies the format of the specified xml file,
@@ -605,7 +605,7 @@ public class Cache
      *          specify the file encoding for the generated xml file.
      *
      *  @throws [java.lang.Exception]
-     *          if something fail during convertion.
+     *          if something fail during conversion.
      */
     public synchronized void toXML(java.io.File     aXML     ,
                                    int              nFormat  ,
@@ -700,7 +700,7 @@ public class Cache
      *          contains the properties in the requested format.
      *
      *  @throws [java.lang.Exception
-     *          if something fail during convertion.
+     *          if something fail during conversion.
      */
     private static java.util.HashMap convertTypePropsToExternal(java.util.HashMap aMap   ,
                                                                 int               nFormat)
@@ -800,7 +800,7 @@ public class Cache
      *          contains the properties in the requested format.
      *
      *  @throws [java.lang.Exception
-     *          if something fail during convertion.
+     *          if something fail during conversion.
      */
     private static java.util.HashMap convertFilterPropsToExternal(java.util.HashMap aMap   ,
                                                                   int               nFormat)
@@ -855,10 +855,10 @@ public class Cache
             //-----------------------------------
             case FORMAT_6Y :
             {
-                // supress "Order" property.
+                // suppress "Order" property.
                 // Will be moved to type entries in 6.y version!
 
-                // supress "UIName" property.
+                // suppress "UIName" property.
                 // Only type entries will be localized in 6.y version!
                 /* TODO make it configurable :-) */
                 aResultMap.put(PROPNAME_UINAME           , aMap.get(PROPNAME_UINAME           ));
@@ -903,7 +903,7 @@ public class Cache
      *          contains the properties in the requested format.
      *
      *  @throws [java.lang.Exception
-     *          if something fail during convertion.
+     *          if something fail during conversion.
      */
     private static java.util.HashMap convertDetectServicePropsToExternal(java.util.HashMap aMap   ,
                                                                          int               nFormat)
@@ -1009,7 +1009,7 @@ public class Cache
     /** converts a type property set (using an external format) to
      *  our internal cache format.
      *
-     *  Especialy the data format string will be expanded
+     *  Especially the data format string will be expanded
      *  to its real properties.
      *
      *  Schema:
@@ -1051,7 +1051,7 @@ public class Cache
 
                 // generate new property "DetectService"
                 // Every type know its detector diretcly from now. No search
                 // will be neccessary any longer.
                 aResultMap.put(PROPNAME_DETECTSERVICE, new java.lang.String());
 
                 // analyze the Data property of the original map
@@ -1132,7 +1132,7 @@ public class Cache
     /** converts a filter property set (using an external format) to
      *  our internal cache format.
      *
-     *  Especialy the data format string will be expanded
+     *  Especially the data format string will be expanded
      *  to its real properties.
      *
      *  Schema:
@@ -1783,7 +1783,7 @@ public class Cache
                 {
                     // last token was not a delimiter - new one is such delim
                     // => ignore this delimiter - but save the information, that
-                    //    it occured
+                    //    it occurred
                     bLastWasDelim = true;
                 }
             }
@@ -1939,7 +1939,7 @@ public class Cache
             java.lang.String  sType = (java.lang.String)aIt1.next();
             java.util.HashMap aType = (java.util.HashMap)m_lTypes.get(sType);
             if (aType == null)
-                throw new java.lang.Exception("type ["+sType+"] dos not exist realy?!");
+                throw new java.lang.Exception("type ["+sType+"] dos not exist really?!");
 
             if (
                 (!aType.containsKey(PROPNAME_MEDIATYPE      )) ||
@@ -1951,7 +1951,7 @@ public class Cache
                 (!aType.containsKey(PROPNAME_UINAME         ))
                )
             {
-                throw new java.lang.Exception("Type \""+sType+"\" does not contain all neccessary properties for a 6.0/6.Y format.");
+                throw new java.lang.Exception("Type \""+sType+"\" does not contain all necessary properties for a 6.0/6.Y format.");
             }
 
             if (
@@ -1973,7 +1973,7 @@ public class Cache
                     (!aType.containsKey(PROPNAME_DETECTSERVICE  ))
                    )
                 {
-                    throw new java.lang.Exception("Type \""+sType+"\" does not contain all neccessary properties for a 6.Y format.");
+                    throw new java.lang.Exception("Type \""+sType+"\" does not contain all necessary properties for a 6.Y format.");
                 }
 
                 if (((java.lang.Integer)aType.get(PROPNAME_UIORDER)).intValue() < 0)
@@ -2023,7 +2023,7 @@ public class Cache
             java.lang.String  sFilter = (java.lang.String)aIt1.next();
             java.util.HashMap aFilter = (java.util.HashMap)m_lFilters.get(sFilter);
             if (aFilter == null)
-                throw new java.lang.Exception("filter ["+sFilter+"] dos not exist realy?!");
+                throw new java.lang.Exception("filter ["+sFilter+"] dos not exist really?!");
 
             if (
                 (!aFilter.containsKey(PROPNAME_DOCUMENTSERVICE  )) ||
@@ -2036,7 +2036,7 @@ public class Cache
                 (!aFilter.containsKey(PROPNAME_USERDATA         ))
                )
             {
-                throw new java.lang.Exception("Filter \""+sFilter+"\" does not contain all neccessary properties for a 6.0/6.Y format.");
+                throw new java.lang.Exception("Filter \""+sFilter+"\" does not contain all necessary properties for a 6.0/6.Y format.");
             }
 
             if (((java.lang.Integer)aFilter.get(PROPNAME_FLAGS)).intValue() < 1)
@@ -2052,7 +2052,7 @@ public class Cache
                     (!aFilter.containsKey(PROPNAME_UINAME))
                    )
                 {
-                    throw new java.lang.Exception("Filter \""+sFilter+"\" does not contain all neccessary properties for a 6.0 format.");
+                    throw new java.lang.Exception("Filter \""+sFilter+"\" does not contain all necessary properties for a 6.0 format.");
                 }
 
                 if (((java.lang.Integer)aFilter.get(PROPNAME_ORDER)).intValue() < 0)
@@ -2112,7 +2112,7 @@ public class Cache
             java.util.HashMap aFilter  = (java.util.HashMap)m_lFilters.get(sFilter);
 
             // remove the "graphic helper filters" used by draw and impress
-            // They dont have any valid document service name set and cant be handled
+            // They dont have any valid document service name set and can't be handled
             // by our generic FrameLoader!
             // They must be moved to her own configuration ...
 
@@ -67,7 +67,7 @@ public class Cache
 
     /** identify the configuration format of an office 6.y.
-     *  Properties are realy xml tags again. */
+     *  Properties are really xml tags again. */
     public static final int FORMAT_6Y = 1;
 
@@ -1051,7 +1051,7 @@ public class Cache
                 // generate new property "DetectService"
                 // Every type know its detector diretcly from now. No search
-                // will be neccessary any longer.
+                // will be necessary any longer.
                 aResultMap.put(PROPNAME_DETECTSERVICE, new java.lang.String());
 

Modified: openoffice/trunk/main/l10ntools/source/filter/utils/ConfigHelper.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/filter/utils/ConfigHelper.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================